@@ -1,5 +1,6 @@
 import datetime
 import logging
+from collections import OrderedDict
 
 from ..data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
@@ -15,7 +16,7 @@ from great_expectations.data_asset import DataAsset
 from .util import send_slack_notification
 from great_expectations.exceptions import ClassInstantiationError
 
-# NOTE: Abe 2019/08/24 : This is first implementation of all these classes. Consider them UNSTABLE for now. 
+# NOTE: Abe 2019/08/24 : This is first implementation of all these classes. Consider them UNSTABLE for now.
 
 
 class ValidationOperator(object):
@@ -71,7 +72,7 @@ class ActionListValidationOperator(ValidationOperator):
         self.data_context = data_context
 
         self.action_list = action_list
-        self.actions = {}
+        self.actions = OrderedDict()
         for action_config in action_list:
             assert isinstance(action_config, dict)
             # NOTE: Eugene: 2019-09-23: need a better way to validate an action config:
@@ -304,7 +305,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
         for suffix in expectation_suite_name_suffixes:
             assert isinstance(suffix, string_types)
         self.expectation_suite_name_suffixes = expectation_suite_name_suffixes
-        
+
         self.slack_webhook = slack_webhook
         self.notify_on = notify_on
 
@@ -324,7 +325,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
                 validation_result_identifier, value in run_return_obj.get("failure").items()
                 if not value["validation_result"].success
             ]
-    
+
         title_block = {
             "type": "section",
             "text": {
@@ -345,7 +346,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
                 "text": "*Status*: {}".format(status_text)},
         }
         query["blocks"].append(status_element)
-        
+
         batch_identifiers_element = {
             "type": "section",
             "text": {
@@ -354,7 +355,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
             }
         }
         query["blocks"].append(batch_identifiers_element)
-    
+
         if not success:
             failed_data_assets_element = {
                 "type": "section",
@@ -364,7 +365,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
                 }
             }
             query["blocks"].append(failed_data_assets_element)
-    
+
         run_id_element = {
             "type": "section",
             "text":
@@ -375,7 +376,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
             ,
         }
         query["blocks"].append(run_id_element)
-        
+
         timestamp_element = {
             "type": "section",
             "text":
@@ -399,7 +400,7 @@ class WarningAndFailureExpectationSuitesValidationOperator(ActionListValidationO
             ],
         }
         query["blocks"].append(footer_section)
-        
+
         return query
 
     def run(self, assets_to_validate, run_id, base_expectation_suite_name=None, evaluation_parameters=None):
